@@ -16,6 +16,7 @@ limitations under the License.
 
 from . import options
 from . import consts
+from cisco_opentelemetry_specifications import Consts
 
 from opentelemetry.sdk.trace.export import ConsoleSpanExporter
 from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import (
@@ -29,12 +30,20 @@ from opentelemetry.exporter.otlp.proto.http.trace_exporter import (
 def _set_exporter(exporter: options.ExporterOptions, opt: options.Options):
     if exporter.exporter_type == consts.GRPC_EXPORTER_TYPE:
         return OTLPGrpcExporter(
-            endpoint=exporter.collector_endpoint, headers=exporter.custom_headers
+            endpoint=exporter.collector_endpoint,
+            headers=exporter.custom_headers
+            if exporter.custom_headers
+            else ((Consts.TOKEN_HEADER_KEY, opt.cisco_token),),
         )
 
     elif exporter.exporter_type == consts.HTTP_EXPORTER_TYPE:
         return OTLPHTTPExporter(
-            endpoint=exporter.collector_endpoint, headers=exporter.custom_headers
+            endpoint=exporter.collector_endpoint,
+            headers=exporter.custom_headers
+            if exporter.custom_headers
+            else {
+                Consts.TOKEN_HEADER_KEY: opt.cisco_token,
+            },
         )
     elif exporter.exporter_type == consts.CONSOLE_EXPORTER_TYPE:
         return ConsoleSpanExporter(service_name=opt.service_name)
